import { useUserinfoStore } from "@/stores/UserinfoStore"
import { $fetch } from 'ohmyfetch'

export interface useAuth {
  login(authCode: string): Promise<void>
  logout(): Promise<void>
  isAuthenticated(): Promise<boolean>
  loadUserInfo(): Promise<void>
}

export default (): useAuth => {
  const userInfoStore = useUserinfoStore()

  return {
    isAuthenticated: async (): Promise<boolean> => {
      return $fetch('/api/userinfo')
        .then(() => true)
        .catch(() => false)
    },

    loadUserInfo: async (): Promise<void> => {
      const userInfo = await $fetch('/api/userinfo')
      userInfoStore.setUserInfo(userInfo)
    },

    login: async (authCode: string): Promise<void> => {
      if (authCode.length != 6) {
        throw Error('login failed')
      }
      const resp = await $fetch(`/api/login?code=${authCode}`)
      if (resp !== 'ok') {
        throw Error('login failed')
      }
    },

    logout: async (): Promise<void> => {
      await $fetch('/api/logout')
    },
  }
}
